@@ -51,6 +51,19 @@
 #define _LP64
 #endif
 
+#if defined(_WIN32)
+#ifndef _WIN32_WINNT
+#define _WIN32_WINNT 0x0501
+#else // _WIN32_WINNT
+#if _WIN32_WINNT < 0x0501
+#error "Headers for Windows XP or later are required"
+#endif // _WIN32_WINNT < 0x0501
+#endif // _WIN32_WINNT
+#ifndef WIN32_LEAN_AND_MEAN
+#define WIN32_LEAN_AND_MEAN 1
+#endif /* !WIN32_LEAN_AND_MEAN */
+#endif // _WIN32
+
 #include <stdio.h>
 #include <stdlib.h>
 #include <stdint.h>
@@ -61,9 +74,11 @@
 #include <fcntl.h>
 #include <signal.h>
 #include <stddef.h>
+#ifdef MHD_USE_POSIX_THREADS
 #undef HAVE_CONFIG_H
 #include <pthread.h>
 #define HAVE_CONFIG_H 1
+#endif // MHD_USE_POSIX_THREADS
 
 /* different OSes have fd_set in
    a broad range of header files;
